<?php
class vatValidation
{
	const WSDL = "https://ec.europa.eu/taxation_customs/vies/checkVatService.wsdl";
	private $_client = null;

	private $options  = array(
						'debug' => false,
						);	
	
	private $_valid = false;
	private $_data = array();
	
	public function __construct($options = array()) {
		
		foreach($options as $option => $value) {
			$this->_options[$option] = $value;
		}
		
		if(!class_exists('SoapClient')) {
			throw new Exception('The Soap library has to be installed and enabled');
		}
				
		try {
			
			 $opts = array(
				'http' => array(
					'user_agent' => 'PHPSoapClient'
				),
				'ssl' => array(
					'verify_peer'       => false,
					'verify_peer_name'  => false,
					'allow_self_signed' => true
				)
			);
			$context = stream_context_create($opts);
			$soapClientOptions = array(
				'stream_context' => $context,
				'cache_wsdl' => WSDL_CACHE_NONE,
				'trace' => true
			);
			$this->_client = new SoapClient(self::WSDL, $soapClientOptions );
		} catch(Exception $e) {
			$this->trace('Vat Translation Error', $e->getMessage());
		}
	}

	public function check($countryCode, $vatNumber) 
	{
		$countryCode = $countryCode == 'GR' ? 'EL' : $countryCode;
		try {
			$rs = $this->_client->checkVat( array('countryCode' => $countryCode, 'vatNumber' => $vatNumber) );
		} catch(Exception $e) { $this->_valid = "no_connection"; return false; } 
		
		if($this->isDebug()) {
			$this->trace('Web Service result', $this->_client->__getLastResponse());	
		}

		if($rs->valid) {
			$this->_valid = true;
			list($denomination,$name) = explode(" " ,$rs->name,2);
			$this->_data = array(
									'denomination' => 	$denomination, 
									'name' => 			$this->cleanUpString($name), 
									'address' => 		$this->cleanUpString($rs->address),
								);
			return true;
		} else {
			$this->_valid = false;
			$this->_data = array();
		    return false;
		}
	}

	public function isValid() {
		return $this->_valid;
	}
	
	public function getDenomination() {
		return $this->_data['denomination'];
	}
	
	public function getName() {
		return $this->_data['name'];
	}
	
	public function getAddress() {
		return $this->_data['address'];
	}
	
	public function isDebug() {
		return ($this->_options['debug'] === true);
	}
	private function trace($title,$body) {
		echo '<h2>TRACE: '.$title.'</h2><pre>'. htmlentities($body).'</pre>';
	}
	private function cleanUpString($string) {
        for($i=0;$i<100;$i++)
        {               
            $newString = str_replace("  "," ",$string);
            if($newString === $string) {
            	break;
            } else {
            	$string = $newString;
			}
        }
                        
        $newString = "";
        $words = explode(" ",$string);
        foreach($words as $k=>$w)
        {                       
           	$newString .= ucfirst(strtolower($w))." "; 
        }                
        return $newString;
	}
}

?>